%global pypi_name reno

# Currently, we cannot generate reno docs from a tarball due to
# https://bugs.launchpad.net/reno/+bug/1520096
%global with_docs 0

%global common_desc \
Reno is a release notes manager for storing \
release notes in a git repository and then building documentation from them. \
\
Managing release notes for a complex project over a long period \
of time with many releases can be time consuming and error prone. Reno \
helps automate the hard parts.

Name:           python-%{pypi_name}
Version:        4.1.0
Release:        %mkrel 1
Summary:        RElease NOtes manager
Group:          Development/Python
License:        ASL 2.0
URL:            https://pypi.org/project/reno
Source0:        %{pypi_source}
Patch0:         reno-relax-dependencies.patch
BuildArch:      noarch

%description
%{common_desc}

%package -n     python3-%{pypi_name}
Summary:        RElease NOtes manager
Group:          Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}

BuildRequires:  pkgconfig(python3)
%if 0%{?with_docs}
BuildRequires:  python3dist(sphinx)
%endif
BuildRequires:  git-core

Requires:       git-core

%description -n python3-%{pypi_name}
%{common_desc}

%package -n python-%{pypi_name}-doc
Summary:        Reno documentation
Group:          Documentation

%description -n python-%{pypi_name}-doc
Documentation for Reno.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

sed -i /.*-c{env:TOX_CONSTRAINTS_FILE.*/d tox.ini
sed -i /^minversion.*/d tox.ini
sed -i /^requires.*virtualenv.*/d tox.ini
sed -i /.*sphinx\]$/d tox.ini

# Exclude some bad-known BRs
for pkg in %{excluded_brs};do
for reqfile in doc/requirements.txt test-requirements.txt; do
if [ -f $reqfile ]; then
sed -i /^${pkg}.*/d $reqfile
fi
done
done

%generate_buildrequires
%if 0%{?with_doc}
  %pyproject_buildrequires -t -e %{default_toxenv},docs
%else
  %pyproject_buildrequires -t -e %{default_toxenv}
%endif

%build
%pyproject_wheel

%install
%pyproject_install

%if 0%{?with_docs}
# generate html docs
%tox -e docs
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}
%endif

%files -n python3-%{pypi_name}
%doc README.rst
%license LICENSE
%{_bindir}/%{pypi_name}
%{python3_sitelib}/%{pypi_name}
%{python3_sitelib}/%{pypi_name}-*.dist-info

%files -n python-%{pypi_name}-doc
%if 0%{?with_docs}
%doc html
%endif
%license LICENSE



%changelog
* Sun Mar 02 2025 daviddavid <daviddavid> 4.1.0-1.mga10
+ Revision: 2156694
- new version: 4.1.0
- rebuild for python 3.13

* Mon Dec 18 2023 papoteur <papoteur> 3.5.0-3.mga10
+ Revision: 2018952
- Mass Rebuild - Python 3.12

* Tue Apr 05 2022 umeabot <umeabot> 3.5.0-2.mga9
+ Revision: 1844822
- Mageia 9 Mass Rebuild

* Sat Feb 19 2022 mrambo3501 <mrambo3501> 3.5.0-1.mga9
+ Revision: 1781522
- version 3.5.0
- rebuild for python-3.10

* Sun Mar 21 2021 daviddavid <daviddavid> 3.3.0-1.mga9
+ Revision: 1706509
- new version: 3.3.0

* Sun Mar 21 2021 daviddavid <daviddavid> 3.2.0-3.mga9
+ Revision: 1706474
- rebuild for python 3.9

* Tue Jan 12 2021 daviddavid <daviddavid> 3.2.0-2.mga8
+ Revision: 1671244
- obsolete old python2-reno

* Sat Nov 28 2020 guillomovitch <guillomovitch> 3.2.0-1.mga8
+ Revision: 1649991
- new version 3.2.0

* Fri Jun 12 2020 kekepower <kekepower> 3.0.1-1.mga8
+ Revision: 1592975
- Update to version 3.0.1

* Sun Feb 16 2020 umeabot <umeabot> 2.11.3-3.mga8
+ Revision: 1533080
- Mageia 8 Mass Rebuild

* Wed Sep 18 2019 tv <tv> 2.11.3-2.mga8
+ Revision: 1443318
- rebuild for python-3.8
- drop python2 subpkg

* Sun Aug 25 2019 wally <wally> 2.11.3-1.mga8
+ Revision: 1431814
- new version 2.11.3

* Tue Jan 08 2019 kekepower <kekepower> 2.11.2-1.mga7
+ Revision: 1352564
- imported package python-reno

